@@ -72,46 +72,236 @@ class SyncManager(QObject):
             del self.active_metadata_thread
             self.active_metadata_thread = None
             self.check_metadata_queue()
-                    
-    def sync_now(self, sync_path):
+            
+    def can_sync(self, sync_path):
         if self.connection.client == None:
             self.ui.show_banner("Cannot synchronize, not connected to Dropbox")
             self.logger.sync("Cannot synchronize, no network connection")
-            return
+            return False
         if self.connection.connection_available() == False:
             self.ui.show_banner("Cannot synchronize, no network connection")
             self.logger.sync("Cannot synchronize, no network connection")
-            return
+            return False
         if self.datahandler.only_sync_on_wlan:
             if not self.connection.connection_is_wlan():
                 self.ui.show_banner("Synchronizing without WLAN disabled in settings", 4000)
-                return
+                return False
         if len(self.controller.transfer_manager.queued_transfer_threads) > 0 or self.controller.transfer_manager.active_transfer != None:
             self.ui.show_banner("There are ongoing active transfers\nPlease wait for them to complete")
-            return    
+            return False    
         if len(self.connection.data_workers) > 0:
             self.ui.show_banner("Data is still being written from previous downloads\nPlease wait a moment and try synchronizing again", 5000)
-            return
+            return False
         if self.sync_ongoing:
             self.ui.show_banner("Synchronization already in progress")
             self.logger.sync("Synchronizing already in progress")
-            return
+            return False
         if sync_path == "" or sync_path == "/":
             self.ui.show_banner("Cannot synchronize, path / invalid")
             self.logger.sync("Cannot synchronize, path / invalid")
-            return
+            return False
         if sync_path == "None":
             self.ui.show_banner("Synchronizing disabled in settings", 2000)
-            return 
+            return False 
         if sync_path[0] != "/":
             self.ui.show_banner("Cannot synchronize, path '" + sync_path + "' invalid")
             self.logger.sync("Cannot synchronize, path '" + sync_path + "' invalid")
-            return
+            return False
         dir_check = QDir(self.datahandler.get_data_dir_path())
         if not dir_check.exists():
             self.ui.show_note("Cannot synchronize, download dir " + self.datahandler.get_data_dir_path() + " does not exist. Please set a new folder in settings.")
+            return False
+        # If got this far, we should be ok to sync
+        return True
+            
+    def sync_media(self):
+        path_local = self.datahandler.user_home + "/MyDocs/DCIM"
+        remote_paths = []
+        path_remote_base = "/N900Media"
+        path_remote_images = "/N900Media/Photos"
+        path_remote_videos = "/N900Media/Videos"
+        remote_paths.append(path_remote_base)
+        remote_paths.append(path_remote_images)
+        remote_paths.append(path_remote_videos)
+        if not self.can_sync(path_remote_base):
             return
+            
+        # Local check
+        if not QDir(path_local).exists():
+            self.logger.sync_error("Could not verify media location from " + path_local)
+            self.ui.show_banner("Errors occurred, check log", 2000)
+            return
+            
+        # Remote base folder check
+        response_images = None
+        response_videos = None
+        response = self.connection.client.metadata("dropbox", path_remote_base, 10000, None)
+        if response.status == 404:
+            answer = QMessageBox.question(self.ui.main_widget, " ", 
+            "You need to create media folders /N900Media/Photos and /N900Media/Videos to dropbox to proceed. \n\nDo you wish to Continue?", QMessageBox.Yes, QMessageBox.No)
+            if answer == QMessageBox.No:
+                return
+                
+            # Create all base, videos and images folder
+            for remote_path in remote_paths:
+                if self.connection.create_folder_blocking(remote_path):
+                    self.logger.info("Created remote folder " + remote_path + " succesfully")
+                else:
+                    self.logger.info("Failed to create remote folder " + remote_path + ", aborting media sync")
+                    self.ui.show_banner("Errors occurred, check log", 2000)
+                    return
+        else:
+            self.ui.show_banner("Preparing media synchronization, please wait...", 2000)
+            # Check images
+            response_images = self.connection.client.metadata("dropbox", path_remote_images, 10000, None)
+            if response_images.status == 404:
+                response_images = None
+                answer = QMessageBox.question(self.ui.main_widget, " ", "You need to create media folder /N900Media/Photos to dropbox to proceed. \n\nDo you wish to Continue?", QMessageBox.Yes, QMessageBox.No)
+                if answer == QMessageBox.No:
+                    return
+                    
+                if self.connection.create_folder_blocking(path_remote_images):
+                    self.logger.info("Created remote folder " + path_remote_images + " succesfully")
+                else:
+                    self.logger.info("Failed to create remote folder " + path_remote_images + ", aborting media sync")
+                    self.ui.show_banner("Errors occurred, check log", 2000)
+                    return
+            # Check videos
+            response_videos = self.connection.client.metadata("dropbox", path_remote_videos, 10000, None)
+            if response_videos.status == 404:
+                response_videos = None
+                answer = QMessageBox.question(self.ui.main_widget, " ", "You need to create media folder /N900Media/Videos to dropbox to proceed. \n\nDo you wish to Continue?", QMessageBox.Yes, QMessageBox.No)
+                if answer == QMessageBox.No:
+                    return
+                    
+                if self.connection.create_folder_blocking(path_remote_videos):
+                    self.logger.info("Created remote folder " + path_remote_videos + " succesfully")
+                else:
+                    self.logger.info("Failed to create remote folder " + path_remote_videos + ", aborting media sync")
+                    self.ui.show_banner("Errors occurred, check log", 2000)
+                    return      
+                    
+        # Folder checks ok, lets sync
+        self.ui.set_synching(True)
+        
+        # Get metadata for both destinations if still needed
+        if response_images == None:
+            response_images = self.connection.client.metadata("dropbox", path_remote_images, 10000, None)
+        if response_videos == None:
+            response_videos = self.connection.client.metadata("dropbox", path_remote_videos, 10000, None)
+            
+        if response_images.status != 200 or response_videos.status != 200:
+            self.logger.sync_error("Error fetching media photos and videos metadata")
+            self.ui.show_banner("Errors occurred, check log", 2000)
+            self.ui.set_synching(False)
+            return
+            
+        # Parse metadatas to get remote file lists
+        data_photos = self.connection.data_parser.parse_metadata_static(response_images.data)
+        data_videos = self.connection.data_parser.parse_metadata_static(response_videos.data)
+        if data_photos == None or data_videos == None:
+            self.logger.sync_error("Error fetching media photos and videos metadata")
+            self.ui.show_banner("Errors occurred, check log", 2000)
+            self.ui.set_synching(False)
+            return
+          
+        # Round up files      
+        remote_files = []
+        for file_obj in data_photos.get_files():
+            remote_files.append(file_obj.get_name())
+        for file_obj in data_videos.get_files():
+            remote_files.append(file_obj.get_name())
+        
+        # Check local folder and compare to remote files
+        sending_local_files = {}
+        for filename in os.listdir(path_local):
+            full_path = path_local + "/" + filename
+            if os.path.isdir(full_path):
+                continue
+            try:
+                found = remote_files.index(filename)
+            except ValueError:
+                sending_local_files[filename] = full_path
+                
+        if len(sending_local_files) == 0:
+            self.ui.show_banner("All media up to date, nothing to upload", 4000)
+            self.ui.set_synching(False)
+            return
+            
+        videos = {}
+        videos_size = 0
+        images = {}
+        images_size = 0
+        for (name, path) in sending_local_files.iteritems():
+            ext = name.split(".")[-1]
+            if ext == "mp4":
+                videos[name] = path
+                videos_size += os.path.getsize(path)
+            else:
+                images[name] = path
+                images_size += os.path.getsize(path)
+        
+        confirmation_ul = SyncDialog(self.ui.main_widget)    
+        confirmation_ul.setWindowTitle("Camera Photos Upload Confirmation")
+        button_ul_all = confirmation_ul.addButton("Upload All", QMessageBox.YesRole)
+        button_ul_photos = confirmation_ul.addButton("Upload Photos", QMessageBox.ActionRole)
+        button_ul_videos = confirmation_ul.addButton("Upload Videos", QMessageBox.DestructiveRole)
+        button_ul_cancel = confirmation_ul.addButton("Cancel", QMessageBox.NoRole)
+        
+        confirmation_ul.add_titles(" ", "Files", "Size")
+        confirmation_ul.add_row("Photos", str(len(images)), self.datahandler.humanize_bytes(images_size))
+        confirmation_ul.add_row("Videos", str(len(videos)), self.datahandler.humanize_bytes(videos_size))
+        confirmation_ul.add_totals(" ", str(len(images)+len(videos)), self.datahandler.humanize_bytes(images_size+videos_size))
+        confirmation_ul.finalize()
+        
+        if len(images) == 0:
+            button_ul_photos.setEnabled(False)
+        if len(videos) == 0:
+            button_ul_videos.setEnabled(False)
 
+        # Photo UL dialog: Upload All = 0, Upload Photos = 1, Cancel = 3, Upload Videos = 2
+        send_photos = False
+        send_videos = False
+        upload_files = 0
+        upload_bytes = 0
+        result = confirmation_ul.exec_()
+        if result == 3:
+            return
+        elif result == 0:
+            send_photos = True
+            send_videos = True
+            upload_files = len(images) + len(videos)
+            upload_bytes = images_size + videos_size
+        elif result == 1:
+            send_photos = True
+            upload_files = len(images)
+            upload_bytes = images_size
+        elif result == 2:
+            send_videos = True
+            upload_files = len(videos)
+            upload_bytes = videos_size
+
+        sync_widget = SyncTransferItem(self)
+        sync_widget.set_totals(0, upload_files)
+        sync_widget.set_sizes("0", self.datahandler.humanize_bytes(upload_bytes))
+        sync_widget.ui.dl_size.hide()
+        self.controller.transfer_manager.set_current_sync(sync_widget)
+        self.controller.transfer_widget.add_sync_reporting(sync_widget)
+        
+        if send_photos:
+            for (name, path) in images.iteritems():
+                self.connection.upload_file(path_remote_images, "dropbox", path, True)
+        if send_videos:
+            for (name, path) in videos.iteritems():
+                self.connection.upload_file(path_remote_videos, "dropbox", path, True)
+                
+        self.ui.set_synching(False)
+        self.ui.show_transfer_widget()
+                
+    def sync_now(self, sync_path):
+        if not self.can_sync(sync_path):
+            return
+            
         self.sync_ongoing = True
         self.sync_fetching_sync_root = True
         self.sync_root = None
